/*********************************************************************************************************
*
* File                : LCD.h
* Hardware Environment: 
* Build Environment   : RealView MDK-ARM  Version: 4.20
* Version             : V1.0
* By                  : 
*
*                                  (c) Copyright 2005-2011, WaveShare
*                                       http://www.waveshare.net
*                                          All Rights Reserved
*
*********************************************************************************************************/

#ifndef __GLCD_H 
#define __GLCD_H

/* Includes ------------------------------------------------------------------*/
#include <math.h>
#include "stm32f4xx.h"
#include "config.h"
#include "AsciiLib.h" 		//  LCD/
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"

/* Private define ------------------------------------------------------------*/
#define USE_16BIT_PMP

/*********************************************************************
* Overview: Horizontal and vertical display resolution
*                  (from the glass datasheet).
*********************************************************************/
//#define DISP_HOR_RESOLUTION				320
//#define DISP_VER_RESOLUTION				240

//#define DISP_ORIENTATION					0
#define DISP_ORIENTATION					90
//#define DISP_ORIENTATION					180
//#define DISP_ORIENTATION					270

/* Private define ------------------------------------------------------------*/

#if  ( DISP_ORIENTATION == 90 ) || ( DISP_ORIENTATION == 270 )
//#define    X
//#define    Y
#define  MAX_X  320
#define  MAX_Y  240   

#elif  ( DISP_ORIENTATION == 0 ) || ( DISP_ORIENTATION == 180 )

#define  MAX_X  240
#define  MAX_Y  320   

#endif

/*********************************************************************
* Overview: Horizontal synchronization timing in pixels
*                  (from the glass datasheet).
*********************************************************************/
//#define DISP_HOR_PULSE_WIDTH		20    /* 20 */
//#define DISP_HOR_BACK_PORCH			51	  /* 48	*/
//#define DISP_HOR_FRONT_PORCH		20	  /* 20 */

/*********************************************************************
* Overview: Vertical synchronization timing in lines
*                  (from the glass datasheet).
*********************************************************************/
//#define DISP_VER_PULSE_WIDTH		2	  /* 2 */
//#define DISP_VER_BACK_PORCH			12	  /* 16 */
//#define DISP_VER_FRONT_PORCH		4	  /* 4 */

/*********************************************************************
* Definition for SPI interface for HIMAX 8238-A relevant to hardware 
* layout; Hardware dependent!
*********************************************************************/
#define GPIO3 3
#define GPIO2 2
#define GPIO1 1
#define GPIO0 0
#define LCD_RESET (1<<GPIO3)	   /* LCD Reset signal (Reset for display panel, NOT ssd1963) */
#define LCD_SPENA (1<<GPIO0)	   /* SPI EN signal */
#define LCD_SPCLK (1<<GPIO1)	   /* SPI CLK */
#define LCD_SPDAT (1<<GPIO2)	   /* SPI DATA */

/* LCD color */
#define White          0xFFFF
#define Black          0x0000
#define Grey           0xF7DE
#define Blue           0x001F
#define Blue2          0x051F
#define Red            0xF800
#define Magenta        0xF81F
#define Green          0x07E0
#define Cyan           0x7FFF
#define Yellow         0xFFE0
/******************************/
/* Define Color Code For GLCD */
/* Color = RRRRR GGGGGG BBBBB */
/******************************/
#define no_bg           0x0001			// No Color Back Ground
#define BLACK           0x0000
#define WHITE           0xFFFF
#define RED             0x8000
#define GREEN           0x0400
#define BLUE            0x0010
#define YELLOW          0xFFF0
#define CYAN            0x0410
#define MAGENTA         0x8010
#define BROWN           0xFC00
#define OLIVE	        0x8400

#define BRIGHT_RED      0xF800
#define BRIGHT_GREEN    0x07E0
#define BRIGHT_BLUE     0x001F
#define BRIGHT_YELLOW   0xFFE0
#define BRIGHT_CYAN     0x07FF
#define BRIGHT_MAGENTA  0xF81F

#define LIGHT_GRAY      0x8410
#define DARK_GRAY       0x4208
#define LIGHT_BLUE      0x841F
#define LIGHT_GREEN     0x87F0
#define LIGHT_CYAN      0x87FF
#define LIGHT_RED       0xFC10
#define LIGHT_MAGENTA   0xFC1F

#define GRAY0       	0xE71C
#define GRAY1         	0xC618
#define GRAY2           0xA514
#define GRAY3           0x630C
#define GRAY4           0x4208
#define GRAY5	        0x2104
#define	GRAY6	        0x3186	

#define	BLUE0	        0x1086	
#define	BLUE1       	0x3188 
#define	BLUE2          	0x4314
#define BLUE3         	0x861C	

#define	CYAN0	        0x3D34
#define	CYAN1           0x1DF7		

#define	GREEN0          0x0200	
#define	GREEN1          0x0208	

//------------ Color For Build Button -------------
#define BT_RED          1
#define BT_GREEN        2
#define BT_BLUE         3
#define	BT_YELLOW       4
#define BT_WHITE        5
#define BT_CYAN         6
#define BT_MAGENTA      7
#define BT_BROWN        8

#define BT_LRED         9
#define BT_LGREEN       10
#define BT_LBLUE        11
#define	BT_LYELLOW      12
#define BT_LWHITE       13
#define BT_LCYAN        14
#define BT_LMAGENTA     15
#define BT_LBROWN       16

#define RGB565CONVERT(red, green, blue) (int) (((red >> 3) << 11) | ((green >> 2) << 5) | (blue >> 3))


/* Private function prototypes -----------------------------------------------*/
void LCD_Initializtion(void);
void LCD_Clear(uint16_t Color);	
//void LCD_SetBacklight(uint8_t intensity);
uint16_t LCD_GetPoint(uint16_t Xpos,uint16_t Ypos);
void LCD_SetPoint(uint16_t Xpos,uint16_t Ypos,uint16_t point);
void PutChar(uint16_t Xpos,uint16_t Ypos,uint8_t c,uint16_t charColor,uint16_t bkColor);
void LCD_DrawLine( uint16_t x0, uint16_t y0, uint16_t x1, uint16_t y1 , uint16_t color );
void PutChinese(uint16_t Xpos,uint16_t Ypos,uint8_t *str,uint16_t Color,uint16_t bkColor); 
void GUI_Text(uint16_t Xpos, uint16_t Ypos, uint8_t *str,uint16_t Color, uint16_t bkColor);
void GUI_Chinese(uint16_t Xpos, uint16_t Ypos, uint8_t *str,uint16_t Color, uint16_t bkColor);	
void LCD_DrawPicture(uint16_t StartX,uint16_t StartY,uint16_t EndX,uint16_t EndY,uint16_t *pic);
void Circle(long CX,long CY,char Radius,char tick,long color,char fill);


void button_build(long px,long py,long width,long high,long c_bt,unsigned char *tx,char num_tx,long c_tx);
void plot_tab_hor(unsigned long color);
void lcd_print3Cha_hor(char ch1,char ch2,char ch3,long cur_x,long cur_y,long fg_color,long bg_color);
void lcd_printStr_hor(char *str,long cur_x,long cur_y,long fg_color,long bg_color);
void text_7x11_hor(char row,long adx,long ady,long fg_clr,long bg_clr);
void plot_dot_hor(unsigned long Xadd,unsigned long Yadd,unsigned long color);
void Rectan(long x1,long y1,long x2,long y2,char tick,long color,char fill);
void plot_mark(long x1,long y1,long x2,long y2,long color);
void Line(long x_1,long y_1,long x_2,long y_2,char line_type,long color);
uint16_t nfabs(long a);
//char status_touch(void);
void text_7x11(char row,long adx,long ady,long fg_clr,long bg_clr);
void plot_picture(const char *bmp,long xad,long yad,long width,long high);
void dec_to_ascii(long num);
void get_point(char num);
void dec_to_ascii(long num);
#endif 

/*********************************************************************************************************
      END FILE
*********************************************************************************************************/

